package cn.com.qmth.examcloud.core.reports.api.provider;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import cn.com.qmth.examcloud.commons.exception.StatusException;
import cn.com.qmth.examcloud.core.reports.api.ProjectCloudService;
import cn.com.qmth.examcloud.core.reports.api.request.GetProjectInfoBeanReq;
import cn.com.qmth.examcloud.core.reports.api.request.UpdateProjectCourseOrgCountReq;
import cn.com.qmth.examcloud.core.reports.api.request.UpdateProjectStatusByIdsReq;
import cn.com.qmth.examcloud.core.reports.api.request.UpdateProjectStatusReq;
import cn.com.qmth.examcloud.core.reports.api.response.GetProjectInfoBeanResp;
import cn.com.qmth.examcloud.core.reports.api.response.UpdateProjectCourseOrgCountResp;
import cn.com.qmth.examcloud.core.reports.api.response.UpdateProjectStatusByIdsResp;
import cn.com.qmth.examcloud.core.reports.api.response.UpdateProjectStatusResp;
import cn.com.qmth.examcloud.core.reports.service.ProjectService;
import cn.com.qmth.examcloud.web.support.ControllerSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

@RestController
@Api(tags = "项目接口")
@RequestMapping("${$rmp.cloud.reports}"+"project")
public class ProjectCloudServiceProvider extends ControllerSupport implements ProjectCloudService {

	
	/**
	 * 
	 */
	private static final long serialVersionUID = 7840494213770095239L;
	@Autowired
	private ProjectService projectService;

	@ApiOperation(value = "修改状态")
    @PostMapping("/updateStatus")
	@Override
	public UpdateProjectStatusResp updateProjectStatus(@RequestBody UpdateProjectStatusReq req) {
		if(req.getProjectId()==null) {
			throw new StatusException("1000001", "projectId不能为空");
		}
		projectService.updateProjectStatus(req);
		return new UpdateProjectStatusResp();
	}

	@ApiOperation(value = "获取项目信息")
    @PostMapping("/getProjectBean")
	@Override
	public GetProjectInfoBeanResp getProjectBean(@RequestBody GetProjectInfoBeanReq req) {
		GetProjectInfoBeanResp res=new GetProjectInfoBeanResp();
		res.setBean(projectService.getProjectInfoBean(req));
		return res;
	}

	@ApiOperation(value = "更新项目中心、课程数量")
    @PostMapping("/updateCourseOrgCount")
	@Override
	public UpdateProjectCourseOrgCountResp updateProjectCourseOrgCount(@RequestBody UpdateProjectCourseOrgCountReq req) {
		if(req.getProjectId()==null) {
			throw new StatusException("1000011", "projectId不能为空");
		}
		projectService.updateProjectCourseOrgCount(req);
		return new UpdateProjectCourseOrgCountResp();
	}

	@ApiOperation(value = "批量修改状态")
    @PostMapping("/updateStatusByIds")
	@Override
	public UpdateProjectStatusByIdsResp updateProjectStatusByIds(@RequestBody UpdateProjectStatusByIdsReq req) {
		projectService.updateProjectStatusByIds(req);
		return new UpdateProjectStatusByIdsResp();
	}

}
